### 安装
```shell
pip install git+https://github.com/link-yundi/ylog.git
```

### 示例

```python
import ylog

ylog.debug('debug msg')
ylog.info('info msg')
ylog.warning('warn msg')
ylog.error('error msg')
```